@@ -17,7 +17,7 @@ use Types::Standard -types;
 use File::ShareDir qw/dist_dir/;
 use YAML qw/LoadFile/;
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 our %warned_once;
 
 has ignore => (
@@ -44,9 +44,8 @@ has exclude_type => (
     default => sub{[]},
 );
 has symlinks => (
-    is      => 'rw',
-    isa     => Bool,
-    default => 0,
+    is  => 'rw',
+    isa => Bool,
 );
 has type_suffixes => (
     is      => 'rw',
@@ -60,12 +59,13 @@ sub BUILD {
     if (!$ENV{HOME}) {
         $ENV{HOME} = $ENV{USERPROFILE};
     }
-    my $dir = dist_dir('File-TypeCategories');
+    my $dir = eval { dist_dir('File-TypeCategories'); };
     my $config_name = '.type_categories.yml';
 
     # import each config file the each subsiquent config overwrites the
     # previous more general config.
     for my $config_dir ($dir, $ENV{HOME}, '.') {
+        next if ! $config_dir || !-d $config_dir;
         my $config_file = "$config_dir/$config_name";
         next if !-f $config_file;
 
@@ -202,7 +202,7 @@ File::TypeCategories - Determine if files match a specific type
 
 =head1 VERSION
 
-This documentation refers to File::TypeCategories version 0.05
+This documentation refers to File::TypeCategories version 0.06
 
 =head1 SYNOPSIS
 
